@@ -926,12 +926,15 @@ export class Glob {
 
 /**
  * Check if a path matches a glob pattern
- * @param {string} path the path to check
- * @param {string} pattern the glob pattern to match
- * @param {boolean} windows whether the path is on a Windows system, defaults to `isWindows`
- * @returns {boolean}
+ * @param path the path to check
+ * @param pattern the glob pattern to match
+ * @param windows whether the path is on a Windows system, defaults to `isWindows`
  */
-export function matchGlobPattern(path, pattern, windows = isWindows) {
+export function matchGlobPattern(
+  path: string,
+  pattern: string,
+  windows = isWindows,
+): boolean {
   validateString(path, "path");
   validateString(pattern, "pattern");
   return lazyMinimatch().default.minimatch(path, pattern, {
