@@ -1612,6 +1612,14 @@ export class ERR_INVALID_IP_ADDRESS extends NodeTypeError {
     super("ERR_INVALID_IP_ADDRESS", `Invalid IP address: ${x}`);
   }
 }
+export class ERR_INVALID_OBJECT_DEFINE_PROPERTY extends NodeTypeError {
+  constructor(message: string) {
+    super(
+      "ERR_INVALID_OBJECT_DEFINE_PROPERTY",
+      message,
+    );
+  }
+}
 export class ERR_INVALID_OPT_VALUE_ENCODING extends NodeTypeError {
   constructor(x: string) {
     super(
@@ -3028,6 +3036,7 @@ export default {
   ERR_INVALID_HTTP_TOKEN,
   ERR_INVALID_IP_ADDRESS,
   ERR_INVALID_MODULE_SPECIFIER,
+  ERR_INVALID_OBJECT_DEFINE_PROPERTY,
   ERR_INVALID_OPT_VALUE,
   ERR_INVALID_OPT_VALUE_ENCODING,
   ERR_INVALID_PACKAGE_CONFIG,
