@@ -6,6 +6,10 @@ use util::TestContextBuilder;
 use util::assert_not_contains;
 use util::testdata_path;
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn compile_basic() {
   let context = TestContextBuilder::new().build();
@@ -57,6 +61,10 @@ fn compile_basic() {
   output.assert_matches_text("Welcome to Deno!\n");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_args() {
   let context = TestContextBuilder::new().build();
@@ -88,6 +96,10 @@ fn standalone_args() {
     .assert_matches_text("a\nb\nfoo\n--bar\n--unstable\n");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_load_datauri() {
   let context = TestContextBuilder::new().build();
@@ -117,6 +129,10 @@ fn standalone_load_datauri() {
 }
 
 // https://github.com/denoland/deno/issues/13704
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_follow_redirects() {
   let context = TestContextBuilder::new().build();
@@ -262,6 +278,10 @@ fn compile_and_overwrite_file() {
   }
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_runtime_flags() {
   let context = TestContextBuilder::new().build();
@@ -298,6 +318,10 @@ fn standalone_runtime_flags() {
     );
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_ext_flag_ts() {
   let context = TestContextBuilder::new().build();
@@ -329,6 +353,10 @@ fn standalone_ext_flag_ts() {
     .assert_matches_text("executing typescript with no extension\n");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_ext_flag_js() {
   let context = TestContextBuilder::new().build();
@@ -359,6 +387,10 @@ fn standalone_ext_flag_js() {
     .assert_matches_text("executing javascript with no extension\n");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_import_map() {
   let context = TestContextBuilder::new().build();
@@ -390,6 +422,10 @@ fn standalone_import_map() {
     .assert_exit_code(0);
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn standalone_import_map_config_file() {
   let context = TestContextBuilder::new().build();
@@ -421,6 +457,10 @@ fn standalone_import_map_config_file() {
     .assert_exit_code(0);
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 // https://github.com/denoland/deno/issues/12670
 fn skip_rebundle() {
@@ -500,6 +540,10 @@ fn check_local_by_default2() {
     );
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn workers_basic() {
   let context = TestContext::with_http_server();
@@ -530,6 +574,10 @@ fn workers_basic() {
     .assert_matches_file("./compile/workers/basic.out");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn workers_not_in_module_map() {
   let context = TestContext::with_http_server();
@@ -559,6 +607,10 @@ fn workers_not_in_module_map() {
   ));
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn workers_with_include_flag() {
   let context = TestContext::with_http_server();
@@ -590,6 +642,10 @@ fn workers_with_include_flag() {
     .assert_matches_text("Hello from worker!\nReceived 42\nClosing\n");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn dynamic_import() {
   let context = TestContext::with_http_server();
@@ -620,6 +676,10 @@ fn dynamic_import() {
     .assert_exit_code(0);
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn dynamic_import_unanalyzable() {
   let context = TestContext::with_http_server();
@@ -772,6 +832,10 @@ testing[WILDCARD]this
     .assert_matches_text("2\n");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn compile_npm_bin_esm() {
   run_npm_bin_compile_test(RunNpmBinCompileOptions {
@@ -788,6 +852,10 @@ fn compile_npm_bin_esm() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn compile_npm_bin_cjs() {
   run_npm_bin_compile_test(RunNpmBinCompileOptions {
     input_specifier: "npm:@denotest/bin/cli-cjs",
@@ -803,6 +871,10 @@ fn compile_npm_bin_cjs() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn compile_npm_cowsay_main() {
   run_npm_bin_compile_test(RunNpmBinCompileOptions {
     input_specifier: "npm:cowsay@1.5.0",
@@ -818,6 +890,10 @@ fn compile_npm_cowsay_main() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn compile_npm_no_permissions() {
   run_npm_bin_compile_test(RunNpmBinCompileOptions {
     input_specifier: "npm:@denotest/cli-with-permissions@1.0.0",
@@ -833,6 +909,10 @@ fn compile_npm_no_permissions() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn compile_npm_cowsay_explicit() {
   run_npm_bin_compile_test(RunNpmBinCompileOptions {
     input_specifier: "npm:cowsay@1.5.0/cowsay",
@@ -848,6 +928,10 @@ fn compile_npm_cowsay_explicit() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn compile_npm_cowthink() {
   run_npm_bin_compile_test(RunNpmBinCompileOptions {
     input_specifier: "npm:cowsay@1.5.0/cowthink",
@@ -921,6 +1005,10 @@ fn run_npm_bin_compile_test(opts: RunNpmBinCompileOptions) {
   output.assert_matches_file(opts.output_file);
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn compile_node_modules_symlink_outside() {
   // this code is using a canonicalized temp dir because otherwise
@@ -989,6 +1077,10 @@ fn compile_node_modules_symlink_outside() {
   output.assert_matches_file("compile/node_modules_symlink_outside/main.out");
 }
 
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 #[test]
 fn compile_node_modules_symlink_non_existent() {
   let context = TestContextBuilder::for_npm().use_temp_cwd().build();
@@ -1033,6 +1125,10 @@ Embedded Files
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn dynamic_imports_tmp_lit() {
   let context = TestContextBuilder::new().build();
   let dir = context.temp_dir();
@@ -1057,6 +1153,10 @@ fn dynamic_imports_tmp_lit() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn granular_unstable_features() {
   let context = TestContextBuilder::new().build();
   let dir = context.temp_dir();
@@ -1084,6 +1184,10 @@ fn granular_unstable_features() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn granular_unstable_features_config_file() {
   let context = TestContextBuilder::new().use_temp_cwd().build();
   let dir = context.temp_dir();
@@ -1121,6 +1225,10 @@ fn granular_unstable_features_config_file() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn dynamic_import_bad_data_uri() {
   let context = TestContextBuilder::new().build();
   let dir = context.temp_dir();
@@ -1150,6 +1258,10 @@ fn dynamic_import_bad_data_uri() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn standalone_config_file_respects_compiler_options() {
   let context = TestContextBuilder::new().build();
   let dir = context.temp_dir();
@@ -1179,6 +1291,10 @@ fn standalone_config_file_respects_compiler_options() {
 }
 
 #[test]
+#[cfg_attr(
+  all(target_os = "macos", target_arch = "x86_64", debug_assertions),
+  ignore // TODO: fix this, see https://github.com/denoland/sui/issues/43
+)]
 fn standalone_jsr_dynamic_import() {
   let context = TestContextBuilder::for_jsr().build();
   let dir = context.temp_dir();
