@@ -297,6 +297,27 @@ fn create_package_version_info(
     serde_json::from_str(&package_json_text)?;
   version_info.insert("dist".to_string(), dist.into());
 
+  // add a bin entry for a directories.bin package.json entry as this
+  // is what the npm registry does as well
+  if let Some(directories) = version_info.get("directories")
+    && !version_info.contains_key("bin")
+    && let Some(bin) = directories
+      .as_object()
+      .and_then(|o| o.get("bin"))
+      .and_then(|v| v.as_str())
+  {
+    let mut bins = serde_json::Map::new();
+    for entry in std::fs::read_dir(version_folder.join(bin))? {
+      let entry = entry?;
+      let file_name = entry.file_name().to_string_lossy().to_string();
+      bins.insert(
+        file_name.to_string(),
+        format!("{}/{}", bin, file_name).into(),
+      );
+    }
+    version_info.insert("bin".into(), bins.into());
+  }
+
   Ok((tarball_bytes, version_info))
 }
 
@@ -488,6 +509,7 @@ fn get_npm_package(
   let mut versions = serde_json::Map::new();
   let mut latest_version = semver::Version::parse("0.0.0").unwrap();
   let mut dist_tags = serde_json::Map::new();
+  let mut time = serde_json::Map::new();
   for entry in fs::read_dir(&package_folder)? {
     let entry = entry?;
     let file_type = entry.file_type()?;
@@ -535,6 +557,10 @@ fn get_npm_package(
       dist_tags.insert(tag.to_string(), version.clone().into());
     }
 
+    if let Some(date) = version_info.get("publishDate") {
+      time.insert(version.clone(), date.clone());
+    }
+
     versions.insert(version.clone(), version_info.into());
     let version = semver::Version::parse(&version)?;
     if version.cmp(&latest_version).is_gt() {
@@ -551,6 +577,7 @@ fn get_npm_package(
   registry_file.insert("name".to_string(), package_name.to_string().into());
   registry_file.insert("versions".to_string(), versions.into());
   registry_file.insert("dist-tags".to_string(), dist_tags.into());
+  registry_file.insert("time".to_string(), time.into());
   Ok(Some(CustomNpmPackage {
     registry_file: serde_json::to_string(&registry_file).unwrap(),
     tarballs,
